==> fox0.99_0.99.87.orig.tar.gz: fox-0.99.87/include/FXGLTriangleMesh.h <==
/********************************************************************************
*                                                                               *
*             O p e n G L   T r i a n g l e   M e s h   O b j e c t             *
*                                                                               *
*********************************************************************************
* Copyright (C) 1999 by Jeroen van der Zijp.   All Rights Reserved.             *
*********************************************************************************
* This library is free software; you can redistribute it and/or                 *
* modify it under the terms of the GNU Library General Public                   *
* License as published by the Free Software Foundation; either                  *
* version 2 of the License, or (at your option) any later version.              *
*                                                                               *
* This library is distributed in the hope that it will be useful,               *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
* Library General Public License for more details.                              *
*                                                                               *
* You should have received a copy of the GNU Library General Public             *
* License along with this library; if not, write to the Free                    *
* Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.            *
*********************************************************************************
* $Id: FXGLTriangleMesh.h,v 1.3 1999/09/29 22:56:57 jeroen Exp $                *
********************************************************************************/
#ifndef FXGLTRIANGLEMESH_H
#define FXGLTRIANGLEMESH_H
    

/*
 * Arrays Formats
 *
 * vertex: x,y,z
 * normal: x,y,z
 * Color: r,g.b,a
 * texture: u,v
 */

class FXAPI FXGLTriangleMesh : public FXGLShape {
  FXDECLARE(FXGLTriangleMesh)
private:
  FXfloat   *vertexBuffer;
  FXfloat   *colorBuffer;
  FXfloat   *normalBuffer;
  FXfloat   *textureBuffer;
  FXint      vertexNumber;
protected:
  FXGLTriangleMesh();
  virtual void drawshape(FXGLViewer* viewer);
  virtual void recomputerange();
  virtual void generatenormals();
public:
  FXGLTriangleMesh(FXfloat x,FXfloat y,FXfloat z,FXint nv,FXfloat *v,FXfloat *n=NULL,FXfloat *c=NULL,FXfloat *t=NULL);
  FXGLTriangleMesh(FXfloat x,FXfloat y,FXfloat z,FXint nv,FXfloat *v,FXfloat *n,FXfloat *c,FXfloat *t,const FXMaterial& mtl);
  virtual void save(FXStream& store) const;
  virtual void load(FXStream& store);
  void setVertexNumber(FXint nvertices){ vertexNumber=nvertices; }
  FXint getVertexNumber() const { return vertexNumber; }
  void setVertexBuffer(FXfloat *vertices);
  void setColorBuffer(FXfloat *colors){ colorBuffer=colors; }
  void setNormalBuffer(FXfloat *normals){ normalBuffer=normals; }
  void setTextureCoordBuffer(FXfloat *textures){ textureBuffer=textures; }
  FXfloat* getVertexBuffer() const { return vertexBuffer; }
  FXfloat* getColorBuffer() const { return colorBuffer; }
  FXfloat* getNormalBuffer() const { return normalBuffer; }
  FXfloat* getTextureCoordBuffer() const { return textureBuffer; }
  virtual ~FXGLTriangleMesh();
  };


#endif

==> fox0.99_0.99.175.orig.tar.gz: fox-0.99.175/include/FXGLTriangleMesh.h <==
/********************************************************************************
*                                                                               *
*             O p e n G L   T r i a n g l e   M e s h   O b j e c t             *
*                                                                               *
*********************************************************************************
* Copyright (C) 1999,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
*********************************************************************************
* This library is free software; you can redistribute it and/or                 *
* modify it under the terms of the GNU Lesser General Public                    *
* License as published by the Free Software Foundation; either                  *
* version 2.1 of the License, or (at your option) any later version.            *
*                                                                               *
* This library is distributed in the hope that it will be useful,               *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
* Lesser General Public License for more details.                               *
*                                                                               *
* You should have received a copy of the GNU Lesser General Public              *
* License along with this library; if not, write to the Free Software           *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
*********************************************************************************
* $Id: FXGLTriangleMesh.h,v 1.7 2001/04/25 05:47:37 jeroen Exp $                *
********************************************************************************/
#ifndef FXGLTRIANGLEMESH_H
#define FXGLTRIANGLEMESH_H
    

/*
 * Arrays Formats
 *
 * vertex: x,y,z
 * normal: x,y,z
 * Color: r,g.b,a
 * texture: u,v
 */


/// OpenGL Triangle Mesh Object
class FXAPI FXGLTriangleMesh : public FXGLShape {
  FXDECLARE(FXGLTriangleMesh)
private:
  FXfloat   *vertexBuffer;
  FXfloat   *colorBuffer;
  FXfloat   *normalBuffer;
  FXfloat   *textureBuffer;
  FXint      vertexNumber;
protected:
  FXGLTriangleMesh();
  virtual void drawshape(FXGLViewer* viewer);
  virtual void recomputerange();
  virtual void generatenormals();
public:

  /// Construct triangle mesh with nv vertices, and optional normals, colors, and texture coordinates
  FXGLTriangleMesh(FXfloat x,FXfloat y,FXfloat z,FXint nv,FXfloat *v,FXfloat *n=NULL,FXfloat *c=NULL,FXfloat *t=NULL);

  /// Construct triangle mesh with nv vertices, and optional normals, colors, and texture coordinates, and surface material
  FXGLTriangleMesh(FXfloat x,FXfloat y,FXfloat z,FXint nv,FXfloat *v,FXfloat *n,FXfloat *c,FXfloat *t,const FXMaterial& mtl);
  
  /// Copy constructor
  FXGLTriangleMesh(const FXGLTriangleMesh& orig);

  /// Copy this object
  virtual FXGLObject* copy();

  /// Change number of vertices
  void setVertexNumber(FXint nvertices){ vertexNumber=nvertices; }

  /// Get number of vertices
  FXint getVertexNumber() const { return vertexNumber; }

  /// Set vertex buffer
  void setVertexBuffer(FXfloat *vertices);
  
  /// Get vertex buffer
  FXfloat* getVertexBuffer() const { return vertexBuffer; }

  /// Set color buffer
  void setColorBuffer(FXfloat *colors){ colorBuffer=colors; }

  /// Get color buffer
  FXfloat* getColorBuffer() const { return colorBuffer; }

  /// Set normals buffer
  void setNormalBuffer(FXfloat *normals){ normalBuffer=normals; }

  /// Get normals buffer
  FXfloat* getNormalBuffer() const { return normalBuffer; }

  /// Set texture coordinate buffer
  void setTextureCoordBuffer(FXfloat *textures){ textureBuffer=textures; }

  /// Get texture coordinate buffer 
  FXfloat* getTextureCoordBuffer() const { return textureBuffer; }

  /// Save to a stream
  virtual void save(FXStream& store) const;

  /// Load from a stream
  virtual void load(FXStream& store);

  /// Destructor
  virtual ~FXGLTriangleMesh();
  };


#endif
